@@ -6,7 +6,7 @@ from nymms.config import yaml_config
 
 class TestIncludeLoader(unittest.TestCase):
     def setUp(self):
-        self.root = os.path.split(__file__)[0]
+        self.root = os.path.dirname(__file__)
 
     def test_relative_include(self):
         full_path = os.path.join(self.root, 'config.yaml')
@@ -17,3 +17,8 @@ class TestIncludeLoader(unittest.TestCase):
     def test_missing_config(self):
         with self.assertRaises(IOError):
             yaml_config.load_config('nonexistant.yaml')
+
+    def test_indent_include(self):
+        full_path = os.path.join(self.root, 'config.yaml')
+        version, relative_config = yaml_config.load_config(full_path)
+        self.assertEqual(relative_config['included']['a'], 1)
